// LANSCA.CCP - February 7, 1996 - Written by J.L. Martinez
//
// Sample program on how to print in landscape.
//
// Comments: I have seen many methods for printing in landscape, but so far
//           this is the simplest I can come up with. At the same time of
//           being able to print in landscape, you can use the DC
//           methods to do some fancy printing through the TPrintDC object.
//
//           I wanted to keep this example very short and concise, so press
//           the Right mouse buttom to print.
//
//           Thank you very much to the people at the Compuserve Borland
//           forum for all their help.

#include <owl/owlpch.h>
#include <owl/applicat.h>
#include <owl/framewin.h>

//**************************************************************************
class TDrawWindow : public TWindow {
	public:
	  TDrawWindow(TWindow* parent = 0);

	protected:
	  // Override member function of TWindow
	  bool CanClose();

	  // Message response functions
	  void EvLButtonDown(uint, TPoint&);
	  void EvRButtonDown(uint, TPoint&);

	DECLARE_RESPONSE_TABLE(TDrawWindow);
};

DEFINE_RESPONSE_TABLE1(TDrawWindow, TWindow)
	EV_WM_LBUTTONDOWN,
	EV_WM_RBUTTONDOWN,
END_RESPONSE_TABLE;

//**************************************************************************
TDrawWindow::TDrawWindow(TWindow* parent)
{
	Init(parent, 0, 0);
}

//**************************************************************************
bool TDrawWindow::CanClose()
{
	return MessageBox("End the program?", "Bye!",
							MB_YESNO | MB_ICONQUESTION) == IDYES;
}

//**************************************************************************
void TDrawWindow::EvLButtonDown(uint, TPoint&)
{
	MessageBox("You have pressed the left mouse button. Press the right mouse buttom to print.",
	  "Message", MB_OK);
}

//**************************************************************************
// Here is the code for printing
void TDrawWindow::EvRButtonDown(uint, TPoint&)
{
static char szPrinter[80];
char *szDevice, *szDriver, *szOutput;
HDC dc;

// Steps for printing in LANDSCAPE
//	1- Define a TPrinter object
//	2- Get the DEVMODE structure
//	3- Modify the DEVMODE structure
// 	4- Get the printer's profile
//	5- Create a DC for the printer
//	6- Create a TPrintDC to use DC methods for printing
//	7- Print whatever you want
//   8- Housekeeping

//Declare the printer object
TPrinter Printer;

//Get the DEVMODE structure
DEVMODE *dm = const_cast <DEVMODE *> (Printer.GetSetup().GetDevMode());
//Modify the DEVMODE structure to print in landscape
dm->dmOrientation = DMORIENT_LANDSCAPE;
dm->dmFields |= DM_ORIENTATION;

//Get the printer's profile
GetProfileString("windows","device",",,,",szPrinter,80);
szDevice = strtok(szPrinter,",");
szDriver = strtok(NULL,",");
szOutput = strtok(NULL,",");

//Create the printer's device context
if(szDevice && szDriver && szOutput)
 {
 dc = CreateDC(szDriver,szDevice,szOutput,dm);
 }

//Create a TPrintDC object to be able to use DC methods for printing
TPrintDC PrintDC(dc);


//Print something
PrintDC.StartDoc("PrintJob",NULL);
PrintDC.StartPage();
PrintDC.TextOut(10,10,"Landscape?");
PrintDC.EndPage();
PrintDC.EndDoc();

//Housekeeping
DeleteDC(dc);

MessageBox("You have pressed the right mouse button and printed in landscape.",
 "Message", MB_OK);

}

//**************************************************************************
class TDrawApp : public TApplication {
	public:
	  TDrawApp() : TApplication() {}

	  void InitMainWindow()
	  {
		 SetMainWindow(new TFrameWindow(0, "Press the Right Mouse Button to print",
			new TDrawWindow));
	  }
};

//**************************************************************************
int OwlMain(int /*argc*/, char* /*argv*/ [])
{
	return TDrawApp().Run();
}



